pub fn load(roots: &[PathBuf], settings: &Value) -> Vec<CartridgePath>Expand description
Settings first, then one per site archive and dw.json.
pub fn load(roots: &[PathBuf], settings: &Value) -> Vec<CartridgePath>Settings first, then one per site archive and dw.json.